# 📜 Code of Conduct for SyckSec

## Our Pledge
We as members, contributors, and leaders pledge to make participation in our community a harassment-free experience for everyone, regardless of age, body size, visible or invisible disability, ethnicity, gender identity and expression, level of experience, education, socio-economic status, nationality, personal appearance, race, religion, or sexual identity and orientation.

We pledge to act and interact in ways that contribute to an open, welcoming, diverse, inclusive, and healthy community.

---

## Our Standards
Examples of behavior that contributes to a positive environment for our community include:

- Demonstrating empathy and kindness toward other people  
- Being respectful of differing opinions, viewpoints, and experiences  
- Giving and gracefully accepting constructive feedback  
- Accepting responsibility and apologizing to those affected by our mistakes, and learning from the experience  
- Focusing on what is best not just for us as individuals, but for the overall community  

Examples of unacceptable behavior include:

- The use of sexualized language or imagery, and sexual attention or advances of any kind  
- Trolling, insulting or derogatory comments, and personal or political attacks  
- Public or private harassment  
- Publishing others’ private information, such as a physical or email address, without their explicit permission  
- Other conduct which could reasonably be considered inappropriate in a professional setting  

---

## Enforcement Responsibilities
Community leaders are responsible for clarifying and enforcing our standards of acceptable behavior and will take appropriate and fair corrective action in response to any behavior they deem inappropriate, threatening, offensive, or harmful.

Community leaders have the right and responsibility to remove, edit, or reject contributions that are not aligned with this Code of Conduct, and will communicate reasons for moderation decisions when appropriate.

---

## Scope
This Code of Conduct applies within all community spaces — including the SyckSec GitHub repository, discussions, social media channels, and live events — and also applies when an individual is officially representing the community in public spaces.

---

## Enforcement
Instances of abusive, harassing, or otherwise unacceptable behavior may be reported to the community leaders responsible for enforcement at:

📧 **conduct@sycksec.com**  

All complaints will be reviewed and investigated promptly and fairly.

---

## Enforcement Guidelines
Community leaders will follow these guidelines in determining the consequences for any action they deem to violate this Code of Conduct:

### 1. Correction
**Community Impact:** Use of inappropriate language or other behavior deemed unprofessional or unwelcome.  
**Consequence:** A private, written warning from community leaders, providing clarity about the nature of the violation and an explanation of why the behavior was inappropriate.

### 2. Warning
**Community Impact:** A violation through a single incident or series of actions.  
**Consequence:** A warning with consequences for continued behavior, such as temporary exclusion from community spaces.

### 3. Temporary Ban
**Community Impact:** A serious violation of community standards, including sustained inappropriate behavior.  
**Consequence:** A temporary ban from any sort of interaction or public communication with the community for a set period.

### 4. Permanent Ban
**Community Impact:** Demonstrating a pattern of violation of community standards or severe harassment.  
**Consequence:** Permanent ban from all community spaces.

---

## Attribution
This Code of Conduct is adapted from the [Contributor Covenant](https://www.contributor-covenant.org) version 2.1.

---

_We believe in making SyckSec not only a secure technology, but also a secure, respectful space for collaboration._
